@@ -5,20 +5,7 @@ use warnings;
 use base qw( Alien::Base );
 
 # ABSTRACT: Find or build flex
-our $VERSION = '0.10'; # VERSION
-
-
-sub bin_dir
-{
-  my($class) = @_;
-  if($class->install_type('system'))
-  {
-    my $path = $class->runtime_prop('system_bin_dir');
-    return ($path) if $path;
-  }
-
-  return $class->SUPER::bin_dir;
-}
+our $VERSION = '0.11'; # VERSION
 
 
 sub alien_helper
@@ -42,7 +29,7 @@ Alien::flex - Find or build flex
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
